@@ -15,14 +15,9 @@ examples = []
 
 
 def example(fn):
-    try:
-        name = 'Example %d' % int(fn.__name__[7:])
-    except:
-        name = fn.__name__
-
     def wrapped():
         try:
-            sys.stdout.write('Running: %s\n' % name)
+            sys.stdout.write('Running: %s\n' % fn.__name__)
             fn()
             sys.stdout.write('\n')
         except KeyboardInterrupt:
@@ -261,14 +256,14 @@ def with_example20():
 
 
 @example
-def with_example21():
+def with_example21a():
     with ProgressBar(maxval=1, redirect_stdout=True) as progress:
         print('', file=sys.stdout)
         progress.update(0)
 
 
 @example
-def with_example21():
+def with_example21b():
     with ProgressBar(maxval=1, redirect_stderr=True) as progress:
         print('', file=sys.stderr)
         progress.update(0)
@@ -296,6 +291,27 @@ def example23():
             progress.update(i)
 
 
+@example
+def example24():
+    pbar = ProgressBar(widgets=[Percentage(), Bar()], maxval=10).start()
+    for i in range(10):
+        # do something
+        time.sleep(0.001)
+        pbar += 1
+    pbar.finish()
+
+
+@example
+def example25():
+    widgets = ['Test: ', Percentage(), ' ', Bar(marker=RotatingMarker()),
+               ' ', ETA(), ' ', FileTransferSpeed()]
+    pbar = ProgressBar(widgets=widgets, maxval=1000, redirect_stdout=True).start()
+    for i in range(100):
+        # do something
+        pbar += 10
+    pbar.finish()
+
+
 if __name__ == '__main__':
     try:
         for example in examples:
