@@ -71,7 +71,7 @@ from progressbar.widgets import *
 __author__ = 'Rick van Hattem'
 __author_email__ = 'Rick.van.Hattem@Fawo.nl'
 __date__ = str(date.today())
-__version__ = '2.6.0'
+__version__ = '2.6.1'
 
 
 class UnknownLength:
@@ -206,6 +206,11 @@ class ProgressBar(object):
     # an iterator.
     next = __next__
 
+    def __iadd__(self, value):
+        'Updates the ProgressBar by adding a new value.'
+        self.update(self.currval + value)
+        return self
+
     def _env_size(self):
         'Tries to find the term_width from the environment.'
 
@@ -278,7 +283,8 @@ class ProgressBar(object):
 
         if value is not None and value is not UnknownLength:
             if (self.maxval is not UnknownLength
-                    and not 0 <= value <= self.maxval):
+                    and not 0 <= value <= self.maxval
+                    and not value < self.currval):
 
                 raise ValueError('Value out of range')
 
@@ -360,4 +366,3 @@ class ProgressBar(object):
         if self.redirect_stdout:
             self._stdout.write(sys.stdout.getvalue())
             sys.stdout = self._stdout
-
